@@ -134,8 +134,6 @@ binomial.CARsepspatial <- function(formula, data=NULL, trials, W, burnin, n.samp
   proposal.sd.beta <- 0.01
   proposal.sd.delta <- 0.05
   proposal.sd.lambda <- 0.02
-  proposal.corr.beta <- solve(t(X.standardised) %*% X.standardised)
-  chol.proposal.corr.beta <- chol(proposal.corr.beta)     
   tau2.shape <- prior.tau2[1] + K/2
   sig2.shape <- prior.tau2[1] + N/2
   
