@@ -131,7 +131,6 @@ samples.fitted <- array(NA, c(n.keep, N.all))
 
 #### Metropolis quantities
 accept <- rep(0,4)
-accept.all <- rep(0,4)
 proposal.sd.phi <- 0.1
 proposal.sd.rho <- 0.02
 Sigma.post.df <- prior.Sigma.df + K * N  
@@ -367,8 +366,7 @@ data.precision <- t(X.standardised) %*% X.standardised
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-      if(ceiling(k)==floor(k))
+      if(ceiling(j/100)==floor(j/100) & j < burnin)
       {
       #### Update the proposal sds
       proposal.sd.phi <- common.accceptrates1(accept[1:2], proposal.sd.phi, 40, 50)
@@ -376,7 +374,6 @@ data.precision <- t(X.standardised) %*% X.standardised
         {
         proposal.sd.rho <- common.accceptrates2(accept[3:4], proposal.sd.rho, 40, 50, 0.5)
         }
-      accept.all <- accept.all + accept
       accept <- c(0,0,0,0)
       }else
       {}
@@ -406,10 +403,10 @@ data.precision <- t(X.standardised) %*% X.standardised
 ###################################
 #### Compute the acceptance rates
 accept.beta <- 100 
-accept.phi <- 100 * accept.all[1] / accept.all[2]
+accept.phi <- 100 * accept[1] / accept[2]
   if(!fix.rho.S)
   {
-  accept.rho <- 100 * accept.all[3] / accept.all[4]
+  accept.rho <- 100 * accept[3] / accept[4]
   }else
   {
   accept.rho <- NA    
